@@ -738,7 +738,7 @@ const char *ssl_cmd_SSLSessionCache(
         mc->nSessionCacheMode      = SSL_SCMODE_SHMHT;
         cp = strchr(arg, ':');
         mc->szSessionCacheDataFile = ap_pstrdup(mc->pPool,
-                                     ssl_util_server_root_relative(cmd->pool, "scache", cp));
+                                     ssl_util_server_root_relative(cmd->pool, "scache", cp+1));
         mc->tSessionCacheDataTable = NULL;
         mc->nSessionCacheDataSize  = 1024*512; /* 512KB */
         if ((cp = strchr(mc->szSessionCacheDataFile, '(')) != NULL) {
@@ -761,7 +761,7 @@ const char *ssl_cmd_SSLSessionCache(
             return "SSLSessionCache: shared memory cache not useable on this platform";
         mc->nSessionCacheMode      = SSL_SCMODE_SHMCB;
         mc->szSessionCacheDataFile = ap_pstrdup(mc->pPool,
-                                     ap_server_root_relative(cmd->pool, arg+5));
+                                     ap_server_root_relative(cmd->pool, arg+6));
         mc->tSessionCacheDataTable = NULL;
         mc->nSessionCacheDataSize  = 1024*512; /* 512KB */
         if ((cp = strchr(mc->szSessionCacheDataFile, '(')) != NULL) {
