@@ -116,13 +116,13 @@
 **  _________________________________________________________________
 */
 
-char *ssl_util_server_root_relative(pool *p, char *arg)
+char *ssl_util_server_root_relative(pool *p, char *what, char *arg)
 {
     char *rv = NULL;
 
 #ifdef SSL_VENDOR
     ap_hook_use("ap::mod_ssl::vendor::ssl_server_root_relative",
-                AP_HOOK_SIG3(ptr,ptr,ptr), AP_HOOK_ALL, &rv, p, arg);
+                AP_HOOK_SIG4(ptr,ptr,ptr,ptr), AP_HOOK_ALL, &rv, p, what, arg);
     if (rv != NULL)
         return rv;
 #endif
